==> bootstrap-italia-2.8.7.jar: META-INF/resources/webjars/bootstrap-italia/2.8.7/types/index.d.ts <==
import { Alert } from './plugins/alert'
import { Accordion } from './plugins/accordion'
import { BackToTop } from './plugins/backToTop'
import { Button } from './plugins/button'
import { Carousel } from './plugins/carousel'
import { CarouselBI } from './plugins/carousel-bi'
import { Collapse } from './plugins/collapse'
import { Cookiebar } from './plugins/cookiebar'
import { Dimmer } from './plugins/dimmer'
import { Dropdown } from './plugins/dropdown'
import { Form } from './plugins/form'
import { FormValidate, ValidatorSelectAutocomplete } from './plugins/form-validate'
import { Forward } from './plugins/forward'
import { HeaderSticky } from './plugins/header-sticky'
import { HistoryBack } from './plugins/history-back'
import { Input } from './plugins/input'
import { InputLabel } from './plugins/input-label'
import { InputNumber } from './plugins/input-number'
import { InputPassword } from './plugins/input-password'
import { InputSearch } from './plugins/input-search-autocomplete'
import { List } from './plugins/list'
import { Masonry } from './plugins/masonry'
import { Modal } from './plugins/modal'
import { NavBarCollapsible } from './plugins/navbar-collapsible'
import { NavScroll } from './plugins/navscroll'
import { Notification } from './plugins/notification'
import { Offcanvas } from './plugins/offcanvas'
import { Popover } from './plugins/popover'
import { ProgressDonut } from './plugins/progress-donut'
import { ScrollSpy } from './plugins/scrollspy'
import { SelectAutocomplete } from './plugins/select-autocomplete'
import { Sticky } from './plugins/sticky'
import { Tab } from './plugins/tab'
import { Toast } from './plugins/toast'
import { Tooltip } from './plugins/tooltip'
import { TrackFocus } from './plugins/track-focus'
import { Transfer } from './plugins/transfer'
import { UploadDragDrop } from './plugins/upload-dragdrop'
import { loadFonts } from './plugins/fonts-loader'

export {
  Alert,
  Accordion,
  BackToTop,
  Button,
  Carousel,
  CarouselBI,
  Collapse,
  Cookiebar,
  Dimmer,
  Dropdown,
  Form,
  FormValidate,
  ValidatorSelectAutocomplete,
  Forward,
  HeaderSticky,
  HistoryBack,
  Input,
  InputLabel,
  InputNumber,
  InputPassword,
  InputSearch,
  List,
  Masonry,
  Modal,
  NavBarCollapsible,
  NavScroll,
  Notification,
  Offcanvas,
  Popover,
  ProgressDonut,
  ScrollSpy,
  SelectAutocomplete,
  Sticky,
  Tab,
  Toast,
  Tooltip,
  TrackFocus,
  Transfer,
  UploadDragDrop,
  loadFonts
}

==> bootstrap-italia-2.13.4.jar: META-INF/resources/webjars/bootstrap-italia/2.13.4/types/index.d.ts <==
import { Alert } from './plugins/alert'
import { Accordion } from './plugins/accordion'
import { BackToTop } from './plugins/back-to-top'
import { Button } from './plugins/button'
import { Carousel } from './plugins/carousel'
import { CarouselBI } from './plugins/carousel-bi'
import { Collapse } from './plugins/collapse'
import { Cookiebar } from './plugins/cookiebar'
import { Dimmer } from './plugins/dimmer'
import { Dropdown } from './plugins/dropdown'
import { Form } from './plugins/form'
import { FormValidate, ValidatorSelectAutocomplete } from './plugins/form-validate'
import { Forward } from './plugins/forward'
import { HeaderSticky } from './plugins/header-sticky'
import { HistoryBack } from './plugins/history-back'
import { Input } from './plugins/input'
import { InputLabel } from './plugins/input-label'
import { InputNumber } from './plugins/input-number'
import { InputPassword } from './plugins/input-password'
import { InputSearch } from './plugins/input-search-autocomplete'
import { List } from './plugins/list'
import { Masonry } from './plugins/masonry'
import { Modal } from './plugins/modal'
import { NavBarCollapsible } from './plugins/navbar-collapsible'
import { NavScroll } from './plugins/navscroll'
import { Notification } from './plugins/notification'
import { Offcanvas } from './plugins/offcanvas'
import { Popover } from './plugins/popover'
import { ProgressDonut } from './plugins/progress-donut'
import { ScrollSpy } from './plugins/scrollspy'
import { SelectAutocomplete } from './plugins/select-autocomplete'
import { Sticky } from './plugins/sticky'
import { Tab } from './plugins/tab'
import { Toast } from './plugins/toast'
import { Tooltip } from './plugins/tooltip'
import { TrackFocus } from './plugins/track-focus'
import { Transfer } from './plugins/transfer'
import { UploadDragDrop } from './plugins/upload-dragdrop'
import { VideoPlayer } from './plugins/video'

import { loadFonts } from './plugins/fonts-loader'

export {
  Alert,
  Accordion,
  BackToTop,
  Button,
  Carousel,
  CarouselBI,
  Collapse,
  Cookiebar,
  Dimmer,
  Dropdown,
  Form,
  FormValidate,
  ValidatorSelectAutocomplete,
  Forward,
  HeaderSticky,
  HistoryBack,
  Input,
  InputLabel,
  InputNumber,
  InputPassword,
  InputSearch,
  List,
  Masonry,
  Modal,
  NavBarCollapsible,
  NavScroll,
  Notification,
  Offcanvas,
  Popover,
  ProgressDonut,
  ScrollSpy,
  SelectAutocomplete,
  Sticky,
  Tab,
  Toast,
  Tooltip,
  TrackFocus,
  Transfer,
  UploadDragDrop,
  VideoPlayer,
  loadFonts
}
